@@ -33,9 +33,10 @@
 
 from server import Server
 import general_ldap
+import auth_pam
 
 
-__all__ = ['Server', 'general_ldap']
+__all__ = ['Server', 'general_ldap', 'auth_pam']
 
 
 # vi: set ai aw sw=2:
