@@ -35,7 +35,7 @@ Allows client to connect and run arbitrary functions in core.py.
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.14'
+__version__ = '0.15'
 
 
 import datetime
@@ -93,6 +93,10 @@ class Server(object):
       self.certfile = self.config_instance.config_file['server'][
           'ssl_cert_file']
     self.inf_renew_time = inf_renew_time
+    self.port = self.config_instance.config_file['server'][
+        'port']
+    self.server_name = self.config_instance.config_file['server'][
+        'host']
     self.core_store_cleanup_running = False
     if( inf_renew_time is None ):
       self.inf_renew_time = self.config_instance.config_file['server'][
@@ -339,13 +343,17 @@ class Server(object):
       return True
     return False
 
-  def Serve(self, server_name=u'localhost', port=8000):
+  def Serve(self, server_name=None, port=None):
     """Main server function
 
     Inputs:
       server_name: name of server you wish to create
       port: listening port number of server
     """
+    if( not port ):
+      port = self.port
+    if( not server_name ):
+      server_name = self.server_name
     if( self.server_killswitch ):
       raise ServerError('"server_killswitch" must be set to "off" in "%s" '
                         'to allow the XML-RPC server to run.' % (
